package com.ycwl.basic.service.impl.mobile;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.ycwl.basic.constant.BaseContextHandler;
import com.ycwl.basic.constant.NumberConstant;
import com.ycwl.basic.mapper.pc.*;
import com.ycwl.basic.model.mobile.index.TopStateResp;
import com.ycwl.basic.model.mobile.scenic.ScenicAppVO;
import com.ycwl.basic.model.mobile.scenic.ScenicDeviceCountVO;
import com.ycwl.basic.model.mobile.scenic.ScenicIndexVO;
import com.ycwl.basic.model.pc.face.req.FaceReqQuery;
import com.ycwl.basic.model.pc.face.resp.FaceRespVO;
import com.ycwl.basic.model.pc.scenic.req.ScenicReqQuery;
import com.ycwl.basic.model.pc.scenic.resp.ScenicRespVO;
import com.ycwl.basic.service.mobile.AppScenicService;
import com.ycwl.basic.utils.ApiResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;

/**
 * @Author：longbinbin
 * @Date：2024/12/6 10:23
 */
@Slf4j
@Service
public class AppScenicServiceImpl implements AppScenicService {

    @Autowired
    private ScenicMapper scenicMapper;
    @Autowired
    private DeviceMapper deviceMapper;
    @Autowired
    private FaceMapper faceMapper;
    @Autowired
    private SourceMapper sourceMapper;
    @Autowired
    private TaskMapper taskMapper;

    @Value("${face.score}")
    private BigDecimal faceScore;

    @Override
    public ApiResponse<PageInfo<ScenicAppVO>> pageQuery(ScenicReqQuery scenicReqQuery) {
        PageHelper.startPage(scenicReqQuery.getPageNum(), scenicReqQuery.getPageSize());
        List<ScenicAppVO> list = scenicMapper.appList(scenicReqQuery);
        PageInfo<ScenicAppVO> pageInfo = new PageInfo<>(list);
        return ApiResponse.success(pageInfo);
    }

    @Override
    public ApiResponse<ScenicDeviceCountVO> deviceCountByScenicId(Long scenicId) {
        String userId = BaseContextHandler.getUserId();
        ScenicDeviceCountVO scenicDeviceCountVO = deviceMapper.deviceCountByScenicId(scenicId, userId);
        return ApiResponse.success(scenicDeviceCountVO);
    }

    @Override
    public ApiResponse<ScenicRespVO> getDetails(Long id) {
        return scenicMapper.getAppById(id);
    }

    @Override
    public ApiResponse<List<ScenicAppVO>> scenicList(ScenicIndexVO scenicIndexVO) {
        List<ScenicAppVO> dataList = scenicMapper.scenicListByLnLa(scenicIndexVO);
        return ApiResponse.success(dataList);
    }

    @Override
    public ApiResponse<TopStateResp> topState() {
        TopStateResp topStateResp = new TopStateResp();
        String userId = BaseContextHandler.getUserId();
        if (StringUtils.isBlank(userId)) {
            return ApiResponse.success(topStateResp);
        }
        // 查询是否有人脸
        FaceReqQuery faceReqQuery = new FaceReqQuery();
        faceReqQuery.setMemberId(Long.parseLong(userId));
        List<FaceRespVO> list = faceMapper.list(faceReqQuery);
        for (FaceRespVO faceRespVO : list) {
            if (faceRespVO.getScore().compareTo(faceScore) >= NumberConstant.ZERO) {
                topStateResp.setIsFace(true);
            }
        }

        // 查询是否有专属视频待制作
        int sourceNum = sourceMapper.countByMemberId(userId);
        topStateResp.setMadeVideos(sourceNum > 0);

        // 是否有专属视频合成中
        int taskSynthesizingNum = taskMapper.countByMemberIdStau(userId);
        topStateResp.setCompositingVideo(taskSynthesizingNum > 0);

        // AI合成了多少个视频 完成
        int taskFinishNum = taskMapper.countByMemberIdStauFinish(userId);
        topStateResp.setAiVideoNum(taskFinishNum);

        return ApiResponse.success(topStateResp);
    }
}
