package com.ycwl.basic.service.impl.pc;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.ycwl.basic.constant.BaseContextHandler;
import com.ycwl.basic.exception.BaseException;
import com.ycwl.basic.mapper.pc.FaceMapper;
import com.ycwl.basic.model.jwt.JwtInfo;
import com.ycwl.basic.model.pc.face.entity.FaceEntity;
import com.ycwl.basic.model.pc.face.req.FaceReqQuery;
import com.ycwl.basic.model.pc.face.resp.FaceRespVO;
import com.ycwl.basic.service.pc.FaceService;
import com.ycwl.basic.utils.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;
import java.util.Date;
import java.util.List;

/**
 * @Author：longbinbin
 * @Date：2024/12/2 16:39
 */
@Slf4j
@Service
public class FaceServiceImpl implements FaceService {
    @Autowired
    private FaceMapper faceMapper;
    @Autowired
    private OssUtil ossUtil;

    @Override
    public ApiResponse<PageInfo<FaceRespVO>> pageQuery(FaceReqQuery faceReqQuery) {
        PageHelper.startPage(faceReqQuery.getPageNum(),faceReqQuery.getPageSize());
        List<FaceRespVO> list = faceMapper.list(faceReqQuery);
        PageInfo<FaceRespVO> pageInfo = new PageInfo<>(list);
        return ApiResponse.success(pageInfo);
    }

    @Override
    public ApiResponse<List<FaceRespVO>> list(FaceReqQuery faceReqQuery) {
        return ApiResponse.success(faceMapper.list(faceReqQuery));
    }

    @Override
    public ApiResponse<FaceRespVO> getById(Long id) {
        return ApiResponse.success(faceMapper.getById(id));
    }

    @Override
    public ApiResponse<Integer> add(FaceEntity face) {
        face.setId(SnowFlakeUtil.getLongId());
        int i = faceMapper.add(face);
        if (i == 0) {
            return ApiResponse.fail("添加失败");
        }
        return ApiResponse.success(i);
    }

    @Override
    public ApiResponse<Integer> deleteById(Long id) {
        int i = faceMapper.deleteById(id);
        if (i == 0) {
            return ApiResponse.fail("删除失败");
        }
        return ApiResponse.success(i);
    }

    @Override
    public ApiResponse<Integer> deleteByIds(List<Long> ids) {
        int i = faceMapper.deleteByIds(ids);
        if (i == 0) {
            return ApiResponse.fail("删除失败");
        }
        return ApiResponse.success(i);
    }

    @Override
    public ApiResponse<Integer> update(FaceEntity face) {
        int i = faceMapper.update(face);
        if (i == 0) {
            return ApiResponse.fail("修改失败");
        }
        return ApiResponse.success(i);
    }

    @Override
    public ApiResponse faceUPload(MultipartFile file) {
        //TODO 获取用户信息
        String userId = BaseContextHandler.getUserId();
        //1、上传人脸照片
        String facaeUrl = uploadFileALiOss(file, userId);
        //TODO 2、人脸照片有效性校验
        Boolean isValid=true;



        if(isValid){
            //校验成功，保存用户人脸信息，将访问人脸照片访问地址响应给前端

            FaceEntity faceEntity = new FaceEntity();
            faceEntity.setId(SnowFlakeUtil.getLongId());
            faceEntity.setMemberId(Long.parseLong(userId));
            faceEntity.setFaceUrl(facaeUrl);
//            faceEntity.setScore();
//            faceEntity.setMatchSampleIds();
//            faceEntity.setFirstMatchRate();
//            faceEntity.setMatchResult();
            //TODO 人脸数据存库
            faceMapper.add(faceEntity);

            return ApiResponse.success(facaeUrl);
        }else {
            //校验失败，删除，提示重新上传
            ossUtil.deleteFile(facaeUrl);

            throw new BaseException("人脸照片校验失败，请重新上传");
        }
    }

    /**
     * 阿里oss图片上传
     *
     * @param file file
     * @param userId 用户id
     * @return 地址
     */
    private String uploadFileALiOss(MultipartFile file,String userId)  {
        if (file.isEmpty()) {
            throw new RuntimeException("文件不存在！");
        }
        String originalFilename = file.getOriginalFilename();
        //获取文件名后缀
        String suffix = originalFilename.split("\\.")[1];
        if ("Jpeg".equals(suffix)) {
            suffix = "jpg";
        }
        //文件储存路径
        String filePath="";
        String dateStr = DateUtils.format(new Date(),"yyyy-MM-dd");

        filePath=filePath+dateStr+"/";
        // 生成文件名
        String fileName= userId+"." + suffix;
        InputStream inputStream ;
        try {
            inputStream = file.getInputStream();
        } catch (IOException e) {
            log.error("文件上传失败！", e);
            return null;
        }
        return ossUtil.uploadFile(inputStream,filePath+fileName) ;
    }
}
