package com.ycwl.basic.service.impl.pc;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.ycwl.basic.mapper.pc.VideoMapper;
import com.ycwl.basic.model.pc.video.entity.VideoEntity;
import com.ycwl.basic.model.pc.video.req.VideoReqQuery;
import com.ycwl.basic.model.pc.video.resp.VideoRespVO;
import com.ycwl.basic.service.pc.VideoService;
import com.ycwl.basic.utils.ApiResponse;
import com.ycwl.basic.utils.SnowFlakeUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：longbinbin
 * @Date：2024/12/3 16:31
 */
@Service
public class VideoServiceImpl implements VideoService {

    @Autowired
    private VideoMapper videoMapper;

    @Override
    public ApiResponse<PageInfo<VideoRespVO>> pageQuery(VideoReqQuery videoReqQuery) {
        PageHelper.startPage(videoReqQuery.getPageNum(), videoReqQuery.getPageSize());
        List<VideoRespVO> list = videoMapper.list(videoReqQuery);
        PageInfo<VideoRespVO> pageInfo = new PageInfo<>(list);
        return ApiResponse.success(pageInfo);
    }

    @Override
    public ApiResponse<List<VideoRespVO>> list(VideoReqQuery videoReqQuery) {
        return ApiResponse.success(videoMapper.list(videoReqQuery));
    }

    @Override
    public ApiResponse<VideoRespVO> getById(Long id) {
        return ApiResponse.success(videoMapper.getById(id));
    }

    @Override
    public ApiResponse<Boolean> add(VideoEntity video) {
        video.setId(SnowFlakeUtil.getLongId());
        int i = videoMapper.add(video);
        if (i > 0) {
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("成片新增失败");
        }
    }

    @Override
    public ApiResponse<Boolean> deleteById(Long id) {
        int i = videoMapper.deleteById(id);
        if (i > 0) {
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("成片删除失败");
        }
    }

    @Override
    public ApiResponse<Boolean> update(VideoEntity video) {
        int i = videoMapper.update(video);
        if (i > 0) {
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("成片修改失败");
        }
    }
}
